@@ -1,8 +1,7 @@
-from ..httpClient import HttpClient
 from ..metaApi_client import MetaApiClient
 from typing_extensions import TypedDict
 from typing import List, Union, Optional, Dict
-from requests import Response
+from httpx import Response
 from enum import Enum
 
 
@@ -98,6 +97,9 @@ class MetatraderAccountDto(TypedDict):
     """API extensions."""
     metadata: Dict
     """Extra information which can be stored together with your account."""
+    reliability: str
+    """Used to increase the reliability of the account. Allowed values are regular, high and maximum.
+    Default is regular."""
 
 
 class NewMetatraderAccountDto(TypedDict):
@@ -133,6 +135,9 @@ class NewMetatraderAccountDto(TypedDict):
     """API extensions."""
     metadata: Dict
     """Extra information which can be stored together with your account."""
+    reliability: str
+    """Used to increase the reliability of the account. Allowed values are regular, high and maximum.
+    Default is regular."""
 
 
 class MetatraderAccountUpdateDto(TypedDict):
